
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.31.5',
    'branch_nick': 'release-1.31',
    'revision_id': 'bc444858f8be964adf249790eedda21939bff8d1',
    'revno': 12501
}
